@@ -411,7 +411,7 @@ def get_all_shared_sets(client,customer_id):
     df = pd.DataFrame(df_dict)
     return df
 
-def get_shared_set_keywords(client,customer_id,shared_set_id):
+def get_shared_set_keywords(client,customer_id,shared_set_id=None):
     df_dict = {
         "shared_set_id": list(),
         "shared_criterion_id": list(),
@@ -419,15 +419,25 @@ def get_shared_set_keywords(client,customer_id,shared_set_id):
         "shared_criterion_keyword_text": list(),
     }
 
-    query = f"""
-    SELECT 
-    shared_set.id,
-    shared_criterion.criterion_id, 
-    shared_criterion.keyword.match_type, 
-    shared_criterion.keyword.text 
-    FROM shared_criterion 
-    WHERE shared_set.id = {shared_set_id} 
-    """
+    if shared_set_id:
+        query = f"""
+        SELECT 
+        shared_set.id,
+        shared_criterion.criterion_id, 
+        shared_criterion.keyword.match_type, 
+        shared_criterion.keyword.text 
+        FROM shared_criterion 
+        WHERE shared_set.id = {shared_set_id} 
+        """
+    else:
+        query = f"""
+        SELECT 
+        shared_set.id,
+        shared_criterion.criterion_id, 
+        shared_criterion.keyword.match_type, 
+        shared_criterion.keyword.text 
+        FROM shared_criterion 
+        """
 
     ga_service = client.get_service("GoogleAdsService")
     search_request = client.get_type("SearchGoogleAdsStreamRequest")
