@@ -54,8 +54,14 @@ df_search_term_report['Keywords2'] = df_search_term_report['keyword_name']
 
 df_search_term_report['sum_conversion'] = df_search_term_report.groupby('date')['metrics_conversions'].transform(sum)
 df_search_term_report_negative = df_search_term_report.loc[df_search_term_report['sum_conversion']==0]
+# df_search_term_report_negative.to_csv(save_path+'/df_search_term_report_negative.csv',index=False)
+
+df_exclude_from_negative = get_shared_set_keywords(googleads_client,customer_id)
+exclude_keywords = df_exclude_from_negative['shared_criterion_keyword_text'].unique().tolist()
+df_search_term_report_negative = df_search_term_report_negative.loc[~df_search_term_report_negative['stv_search_term'].isin(exclude_keywords)]
+df_search_term_report_negative = df_search_term_report_negative.loc[df_search_term_report_negative['metrics_cost']>0]
 df_search_term_report_negative = df_search_term_report_negative.drop_duplicates("stv_search_term")
-# df_search_term_report_negative = df_search_term_report_negative.merge(df_existing.loc[:,['adgroup_id','keyword_name']],on='adgroup_id',how='left')
+# df_search_term_report_negative.to_csv(save_path+'/df_search_term_report_negative.csv',index=False)
 
 df_search_term_report = df_search_term_report.loc[df_search_term_report['metrics_conversions']>=conversion_threshold]
 df_search_term_report = df_search_term_report[~df_search_term_report["Keywords"].isin(keywords_to_remove)]
@@ -297,38 +303,33 @@ if len(df_search_term_report_negative) != 0:
     df_search_term_report_negative.to_csv(save_path+'/df_search_term_report_negative.csv',index=False)
 
     if len(df_search_term_report_negative) != 0:
-        if len(df_search_term_report_negative) != 0:
-            answer = input("Do you want to upload negative keywords? (y/n): ")
-            if answer == 'y' or answer == 'Y':
-                print("Get Shared Set List")
-                df_shared_set = get_all_shared_sets(googleads_client,customer_id)
-                for i,row in df_shared_set.iterrows():
-                    print("No - Id - Name")
-                    print(f"{i} - {row['shared_set_id']} - {row['shared_set_name']}")
-                answer = int(input("Select the number from above list: "))
-                shared_set_id = df_shared_set.loc[i].at['shared_set_id']
-                df_exclude = get_shared_set_keywords(googleads_client,customer_id,shared_set_id)
-                exclude_keywords = df_exclude['shared_criterion_keyword_text'].unique().tolist()
-                negative_keywords = df_search_term_report_negative['stv_search_term'].unique().tolist()
-                negative_keywords = [x for x in negative_keywords if x not in exclude_keywords]
-                negative_keywords = [x for x in negative_keywords if len(x) <= 80]
-                if len(negative_keywords) != 0:
-                    resourse_names_list1 = add_negative_keywords(googleads_client,customer_id,shared_set_id,negative_keywords,kw_type='PHRASE')
-                    resourse_names_list2 = add_negative_keywords(googleads_client,customer_id,shared_set_id,negative_keywords,kw_type='EXACT')
+        answer = input("Do you want to upload negative keywords? (y/n): ")
+        if answer == 'y' or answer == 'Y':
+            print("Get Shared Set List")
+            df_shared_set = get_all_shared_sets(googleads_client,customer_id)
+            for i,row in df_shared_set.iterrows():
+                print("No - Id - Name")
+                print(f"{i} - {row['shared_set_id']} - {row['shared_set_name']}")
+            answer = int(input("Select the number from above list: "))
+            shared_set_id = df_shared_set.loc[i].at['shared_set_id']
+            negative_keywords = df_search_term_report_negative['stv_search_term'].unique().tolist()
+            negative_keywords = [x for x in negative_keywords if x not in exclude_keywords]
+            negative_keywords = [x for x in negative_keywords if len(x) <= 80]
+            if len(negative_keywords) != 0:
+                resourse_names_list1 = add_negative_keywords(googleads_client,customer_id,shared_set_id,negative_keywords,kw_type='PHRASE')
+                resourse_names_list2 = add_negative_keywords(googleads_client,customer_id,shared_set_id,negative_keywords,kw_type='EXACT')
 
-                    keyword_ids1 = [x.resource_name.split('~')[-1] for x in resourse_names_list1]
-                    keyword_ids2 = [x.resource_name.split('~')[-1] for x in resourse_names_list2]
+                keyword_ids1 = [x.resource_name.split('~')[-1] for x in resourse_names_list1]
+                keyword_ids2 = [x.resource_name.split('~')[-1] for x in resourse_names_list2]
 
-                    info_dict['campaign_id'].extend(len(keyword_ids1)*["-"])
-                    info_dict['adgroup_id'].extend(len(keyword_ids1)*["-"])
-                    info_dict['shared_set_id'].extend(len(keyword_ids1)*[str(shared_set_id)])
-                    info_dict['keyword_id'].extend(keyword_ids1)
-                    info_dict['keyword_id2'].extend(keyword_ids2)
-                    info_dict['type'].extend(len(keyword_ids1)*["negative"])
-                else:
-                    print("No keywords to add in negative list")
-        else:
-            print("No keywords to add in negative list")
+                info_dict['campaign_id'].extend(len(keyword_ids1)*["-"])
+                info_dict['adgroup_id'].extend(len(keyword_ids1)*["-"])
+                info_dict['shared_set_id'].extend(len(keyword_ids1)*[str(shared_set_id)])
+                info_dict['keyword_id'].extend(keyword_ids1)
+                info_dict['keyword_id2'].extend(keyword_ids2)
+                info_dict['type'].extend(len(keyword_ids1)*["negative"])
+            else:
+                print("No keywords to add in negative list")
     else:
         print("No keywords to add in negative list")
 else:
