@@ -3,7 +3,6 @@ import pandas as pd
 from google.ads.googleads.client import GoogleAdsClient
 from google.ads.googleads.errors import GoogleAdsException
 
-df_path = 'M:/Upwork/OpenMoves/OpenMoves/401k_sim_ext_downstream1.csv'
 path = 'M:/GAds/google-ads_something.yaml'
 customer_id = '6554081276'
 threshold = 0.9
@@ -98,7 +97,9 @@ def get_existing():
           campaign.status,
           campaign.name
         FROM campaign
-        ORDER BY campaign.id"""
+        WHERE campaign.status IN ('PAUSED', 'ENABLED')
+        """
+        # ORDER BY campaign.id
 
     # Issues a search request using streaming.
     stream = ga_service.search_stream(customer_id=customer_id, query=query)
@@ -129,19 +130,14 @@ def get_existing():
                         f"with ID {ad_group.id}.")
                     camps['camp_name'].append(camp_row.campaign.name)
                     camps['camp_id'].append(camp_row.campaign.id)
-                    camps['camp_status'].append(camp_row.campaign.status)
+                    camps['camp_status'].append(camp_row.campaign.status.name)
                     camps['adgroup_name'].append(grp_row.ad_group.name)
                     camps['adgroup_id'].append(grp_row.ad_group.id)
-                    camps['adgroup_status'].append(grp_row.ad_group.status)
+                    camps['adgroup_status'].append(grp_row.ad_group.status.name)
                     camps['keyword_name'].append(keyword.text)
-                    camps['keyword_type'].append(keyword.match_type)
+                    camps['keyword_type'].append(keyword.match_type.name)
                     camps['keyword_id'].append(row.ad_group_criterion.criterion_id)
         df = pd.DataFrame.from_dict(camps)
-        df['camp_status'] = df['camp_status'].apply(lambda x: status[x-1])
-        df['adgroup_status'] = df['adgroup_status'].apply(
-            lambda x: status[x-1])
-        df['keyword_type'] = df['keyword_type'].apply(
-            lambda x: keyword_type[x-1])
         df.to_csv('existing.csv', index=False)
 
 
